<?php

/**
 * Theme functions and definitions.
 * @author  	 DeoThemes
 * @copyright  (c) Copyright by DeoThemes
 * @link       https://deothemes.com
 * @package 	 Ona
 * @since 		 1.0
 */
if ( !defined( 'ABSPATH' ) ) {
    exit( 'Direct script access denied.' );
}
// Set the content width based on the theme's design and stylesheet.

if ( !isset( $content_width ) ) {
    $content_width = 1170;
    /* pixels */
}

// Constants
define( 'ONA_VERSION', '1.2.2' );
define( 'ONA_DIR', get_template_directory() );
define( 'ONA_URI', get_template_directory_uri() );

if ( !function_exists( 'ona_fs' ) ) {
    // Create a helper function for easy SDK access.
    function ona_fs()
    {
        global  $ona_fs ;
        
        if ( !isset( $ona_fs ) ) {
            // Include Freemius SDK.
            require_once dirname( __FILE__ ) . '/freemius/start.php';
            $ona_fs = fs_dynamic_init( array(
                'id'               => '9271',
                'slug'             => 'ona',
                'type'             => 'theme',
                'public_key'       => 'pk_561bffcf4255bd719dad9701963a8',
                'is_premium'       => false,
                'premium_suffix'   => 'Pro',
                'has_addons'       => false,
                'has_paid_plans'   => true,
                'is_org_compliant' => true,
                'menu'             => array(
                'slug'    => 'ona-theme',
                'support' => false,
                'parent'  => array(
                'slug' => 'themes.php',
            ),
            ),
                'is_live'          => true,
            ) );
        }
        
        return $ona_fs;
    }
    
    // Init Freemius.
    ona_fs();
    // Signal that SDK was initiated.
    do_action( 'ona_fs_loaded' );
}

// Includes
require_once ONA_DIR . '/inc/admin/theme-admin.php';
require_once ONA_DIR . '/inc/block-patterns.php';
/*--------------------------------------------------------------
# Theme Supports
--------------------------------------------------------------*/

if ( !function_exists( 'ona_setup' ) ) {
    function ona_setup()
    {
        load_theme_textdomain( 'ona', get_template_directory() . '/languages' );
        add_theme_support( 'post-thumbnails' );
        set_post_thumbnail_size( 1170, 0 );
        add_theme_support( 'editor-styles' );
        add_theme_support( 'html5', array( 'comment-form', 'comment-list' ) );
        add_theme_support( 'responsive-embeds' );
        // Adding support for core block visual styles.
        add_theme_support( 'wp-block-styles' );
        // Disable WooCommerce wizard redirect
        add_filter( 'woocommerce_enable_setup_wizard', '__return_false' );
        add_filter( 'woocommerce_show_admin_notice', '__return_false' );
        add_filter( 'woocommerce_prevent_automatic_wizard_redirect', '__return_false' );
    }
    
    add_action( 'after_setup_theme', 'ona_setup' );
}

/*--------------------------------------------------------------
# Enqueue Styles
--------------------------------------------------------------*/

if ( !function_exists( 'ona_styles' ) ) {
    function ona_styles()
    {
        wp_register_style( 'ona-style', ONA_URI . '/assets/css/style.min.css' );
        wp_add_inline_style( 'ona-style', ona_get_font_face_styles() );
        $dependencies = apply_filters( 'ona_style_dependencies', array( 'ona-style' ) );
        wp_register_style(
            'ona-style-blocks',
            ONA_URI . '/assets/css/blocks.min.css',
            $dependencies,
            ONA_VERSION
        );
        wp_enqueue_style( 'ona-style' );
        wp_style_add_data( 'ona-style', 'rtl', 'replace' );
        wp_enqueue_style( 'ona-style-blocks' );
        wp_style_add_data( 'ona-style-blocks', 'rtl', 'replace' );
    }
    
    add_action( 'wp_enqueue_scripts', 'ona_styles' );
}

/*--------------------------------------------------------------
# Enqueue Editor Styles
--------------------------------------------------------------*/

if ( !function_exists( 'ona_editor_styles' ) ) {
    function ona_editor_styles()
    {
        add_editor_style( array( './assets/css/editor.min.css', './assets/css/blocks.min.css' ) );
        wp_add_inline_style( 'wp-block-library', ona_get_font_face_styles() );
    }
    
    add_action( 'admin_init', 'ona_editor_styles' );
}

/*--------------------------------------------------------------
# Enqueue Admin Scripts and Styles
--------------------------------------------------------------*/

if ( !function_exists( 'ona_admin_scripts' ) ) {
    function ona_admin_scripts()
    {
        $screen = get_current_screen();
        wp_enqueue_style( 'ona-admin-styles', ONA_URI . '/assets/admin/css/admin-styles.css' );
        
        if ( $screen->id === 'appearance_page_ona-theme' ) {
            wp_enqueue_script(
                'ona-admin-scripts',
                ONA_URI . '/assets/admin/js/admin-scripts.js',
                array( 'jquery-core' ),
                false,
                true
            );
            wp_localize_script( 'ona-admin-scripts', 'ona_params', array(
                'ajaxurl'    => admin_url( 'admin-ajax.php' ),
                'wpnonce'    => wp_create_nonce( 'ona_ajax_nonce' ),
                'wizard_url' => esc_url( admin_url( 'themes.php?page=merlin' ) ),
                'processing' => esc_html__( 'Processing', 'ona' ),
                'finished'   => esc_html__( 'Finished', 'ona' ),
            ) );
        }
    
    }
    
    add_action( 'admin_enqueue_scripts', 'ona_admin_scripts' );
}

/*--------------------------------------------------------------
# Get Fonts
--------------------------------------------------------------*/
if ( !function_exists( 'ona_get_font_face_styles' ) ) {
    /**
     * Get font face styles.
     *
     * @return string
     */
    function ona_get_font_face_styles()
    {
        return "\n\t\t@font-face{\n\t\t\tfont-family: 'Gilda Display';\n\t\t\tfont-weight: normal;\n\t\t\tfont-style: normal;\n\t\t\tfont-stretch: normal;\n\t\t\tsrc: url('" . get_theme_file_uri( 'assets/fonts/gilda-display/GildaDisplay-Regular.woff' ) . "') format('woff');\n\t\t}\n\n\t\t@font-face{\n\t\t\tfont-family: 'Nunito Sans';\n\t\t\tfont-weight: normal;\n\t\t\tfont-style: normal;\n\t\t\tfont-stretch: normal;\n\t\t\tsrc: url('" . get_theme_file_uri( 'assets/fonts/nunito-sans/NunitoSans-Regular.woff' ) . "') format('woff');\n\t\t}\n\n\t\t@font-face{\n\t\t\tfont-family: 'Nunito Sans';\n\t\t\tfont-weight: normal;\n\t\t\tfont-style: italic;\n\t\t\tfont-stretch: normal;\n\t\t\tsrc: url('" . get_theme_file_uri( 'assets/fonts/nunito-sans/NunitoSans-Italic.woff' ) . "') format('woff');\n\t\t}\n\n\t\t@font-face{\n\t\t\tfont-family: 'Nunito Sans';\n\t\t\tfont-weight: 600;\n\t\t\tfont-style: normal;\n\t\t\tfont-stretch: normal;\n\t\t\tsrc: url('" . get_theme_file_uri( 'assets/fonts/nunito-sans/NunitoSans-SemiBold.woff' ) . "') format('woff');\n\t\t}\n\n\t\t@font-face{\n\t\t\tfont-family: 'Nunito Sans';\n\t\t\tfont-weight: 700;\n\t\t\tfont-style: normal;\n\t\t\tfont-stretch: normal;\n\t\t\tsrc: url('" . get_theme_file_uri( 'assets/fonts/nunito-sans/NunitoSans-Bold.woff' ) . "') format('woff');\n\t\t}\n\n\t\t";
    }

}